@@ -21,21 +21,17 @@
 
 #include <gtk/gtk.h>
 
-#define LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
+#define _LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
 
 #include <libxfce4panel/libxfce4panel-config.h>
 #include <libxfce4panel/libxfce4panel-enums.h>
 #include <libxfce4panel/libxfce4panel-enum-types.h>
 #include <libxfce4panel/xfce-panel-macros.h>
-#include <libxfce4panel/xfce-panel-macros-46.h>
 #include <libxfce4panel/xfce-arrow-button.h>
-#if !GTK_CHECK_VERSION (3, 0, 0)
-#include <libxfce4panel/xfce-hvbox.h>
-#endif
 #include <libxfce4panel/xfce-panel-convenience.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 #include <libxfce4panel/xfce-panel-image.h>
 
-#undef LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
+#undef _LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
 
 #endif /* !__LIBXFCE4PANEL__ */
